<?php

/**
 * Created by PhpStorm.
 * User: wangzhiqiang
 * Date: 2019/5/5
 * Time: 17:11
 */
namespace App\Traits;
use Illuminate\Support\Facades\Redis;
use Tymon\JWTAuth\Facades\JWTAuth;

trait UserTrait
{

    public function getUserInfo() {
        try {
            $sign = generateSign([], config('customer.app_secret'));
            $url = config("customer.app_service_url").'/user/userInfo';
            $array = [
                'json' => ['sign' => $sign], 'query' => [], 'http_errors' => false,'headers'=>['Authorization'=>"Bearer ".JWTAuth::getToken()]
            ];
            return http($url,$array);
        } catch (\Exception $e) {
            return [];
        }

    }

    //获取用户信息
    public function userInfo($uid) {
        $user = Redis::HGETALL('userInfo:' . $uid);
        if(!$user){
            try {
                $sign = generateSign(['uid' => $uid], config('customer.app_secret'));
                $url = config("customer.app_service_url").'/user/getUserInfo';
                $array = [
                    'json' => ['sign' => $sign,'uid' => $uid], 'query' => [], 'http_errors' => false,'headers'=>['Authorization'=>"Bearer ".JWTAuth::getToken()]
                ];
                $user =  http($url,$array,'get');
            } catch (\Exception $e) {
                $user =  [];
            }
        }
        if(!$user){
            $user = [
                'uid' => $uid,
                'username' => '老板',
                'avatar' => 'http://oss.caihongxingqiu.net/201907/1564471458_5d3ff0a231721.png?280_280',
                'gender' => 2,
                'invite_code' => ''
            ];
        }
        return $user;
    }

    public function getBanner($ids) {
        try {
            $sign = generateSign(['ids' => $ids], config('customer.app_secret'));
            $url = config("customer.app_service_url").'/config/v2/bannerSet/lists';
            $array = [
                'json' => ['sign' => $sign, 'ids' => $ids], 'query' => [], 'http_errors' => false,'headers'=>['Authorization'=>"Bearer ".JWTAuth::getToken()]
            ];
            return http($url,$array,'get');
        } catch (\Exception $e) {
            return [];
        }

    }

    public function getTopic($ids) {
        try {
            $sign = generateSign(['ids' => $ids], config('customer.app_secret'));
            $url = config("customer.app_service_url").'/community/topic/group';
            $array = [
                'json' => ['sign' => $sign, 'ids' => $ids], 'query' => [], 'http_errors' => false,'headers'=>['Authorization'=>"Bearer ".JWTAuth::getToken()]
            ];
            return http($url,$array,'get');
        } catch (\Exception $e) {
            return [];
        }

    }

    public function getPostVideo($ids) {
        try {
            $sign = generateSign(['ids' => $ids], config('customer.app_secret'));
            $url = config("customer.app_service_url").'/community/post/video/group';
            $array = [
                'json' => ['sign' => $sign, 'ids' => $ids], 'query' => [], 'http_errors' => false,'headers'=>['Authorization'=>"Bearer ".JWTAuth::getToken()]
            ];
            return http($url,$array,'get');
        } catch (\Exception $e) {
            return [];
        }

    }

    public function getMemberGroup($ids) {
        try {
            $sign = generateSign(['ids' => $ids], config('customer.app_secret'));
            $url = config("customer.app_service_url").'/user/userGroup';
            $array = [
                'json' => ['sign' => $sign, 'ids' => $ids], 'query' => [], 'http_errors' => false,'headers'=>['Authorization'=>"Bearer ".JWTAuth::getToken()]
            ];
            return http($url,$array,'get');
        } catch (\Exception $e) {
            return [];
        }

    }
    //获取推荐用户根据id排序
    public function getMemberSortIdList($ids) {
        try {
            $sign = generateSign(['uids' => $ids], config('customer.app_secret'));
            $url = config("customer.app_service_url").'/user/v2/member/memberSortIdList';
            //$url = 'http://localhost:8080/v2/member/memberSortIdList';
            $array = [
                'json' => ['sign' => $sign, 'uids' => $ids], 'query' => [], 'http_errors' => false,'headers'=>['Authorization'=>"Bearer ".JWTAuth::getToken()]
            ];
            return http($url,$array,'get');
        } catch (\Exception $e) {
            return [];
        }

    }

    //获取关注状态
    public function getFollowStatus($uid, $followUid)
    {
        $status = 0;
        if(Redis::ZSCORE('follow:'.$uid, $followUid)){
            $status = 1;
            if(Redis::ZSCORE('follow:'.$followUid, $uid)){
                $status = 2;
            }
        }
        return $status;
    }
}